@@ -107,8 +107,15 @@ logger.addHandler(logger_console_handler)
 
 class OMCSessionHelper():
   def __init__(self):
-    self.omhome = os.environ.get('OPENMODELICAHOME') or os.path.split(os.path.split(os.path.realpath(spawn.find_executable("omc")))[0])[0]
-
+    # Get the path to the OMC executable, if not installed this will be None
+    omc_env_home = os.environ.get('OPENMODELICAHOME')
+    if omc_env_home:
+      self.omhome = omc_env_home
+    else:
+      path_to_omc = spawn.find_executable("omc")
+      if path_to_omc is None:
+        raise ValueError("Cannot find OpenModelica executable, please install from openmodelica.org")
+      self.omhome = os.path.split(os.path.split(os.path.realpath(path_to_omc))[0])[0]
   def _get_omc_path(self):
     try:
       return os.path.join(self.omhome, 'bin', 'omc')
